searchData={"items":[{"type":"module","title":"AbsintheRateLimiting","doc":"`absinthe_rate_limiting` is a middleware-based rate limiter for\n[Absinthe](https://hexdocs.pm/absinthe/overview.html) that uses\n[Hammer](https://hexdocs.pm/hammer/index.html).","ref":"AbsintheRateLimiting.html"},{"type":"module","title":"Installation - AbsintheRateLimiting","doc":"`absinthe_rate_limiting` is [available in\nHex](https://hexdocs.pm/absinthe_rate_limiting), and can be installed by adding\n`:absinthe_rate_limiting` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:absinthe_rate_limiting, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"AbsintheRateLimiting.html#module-installation"},{"type":"module","title":"Basic usage - AbsintheRateLimiting","doc":"To use the rate limiting middleware, you must first configure Hammer. For example:\n\n```elixir\nconfig :hammer,\n  backend:\n    {Hammer.Backend.ETS, [\n      expiry_ms: 1000 * 60 * 60 * 4,\n      cleanup_interval_ms: 1000 * 60 * 10\n    ]}\n```\n\nSee the [Hammer documentation](https://hexdocs.pm/hammer) for more information.\n\nThe next step is to add the middleware to the query that needs to be rate\nlimited:\n\n```elixir\nfield :my_field, :string do\n  middleware AbsintheRateLimiting.RateLimit\n  resolve &MyApp.Resolvers.my_field/3\nend\n```\n\nFor the full usage information, see `AbsintheRateLimiting.RateLimit`.","ref":"AbsintheRateLimiting.html#module-basic-usage"},{"type":"module","title":"AbsintheRateLimiting.RateLimit","doc":"Rate limiting middleware for Absinthe.","ref":"AbsintheRateLimiting.RateLimit.html"},{"type":"module","title":"Usage - AbsintheRateLimiting.RateLimit","doc":"To use the rate limiting middleware, you must first configure Hammer. For example:\n\n    config :hammer,\n      backend:\n        {Hammer.Backend.ETS, [\n          expiry_ms: 1000 * 60 * 60 * 4,\n          cleanup_interval_ms: 1000 * 60 * 10\n        ]}\n\nSee the [Hammer documentation](https://hexdocs.pm/hammer) for more information.\n\nThe next step is to add the middleware to all queries that needs to be rate\nlimited:\n\n    field :my_field, :string do\n      middleware AbsintheRateLimiting.RateLimit\n      resolve &MyApp.Resolvers.my_field/3\n    end","ref":"AbsintheRateLimiting.RateLimit.html#module-usage"},{"type":"module","title":"Configuration - AbsintheRateLimiting.RateLimit","doc":"The available configuration options are:\n\n| Option       | Description                                                                                                                                                                                                                                                     | Default Value                  |\n|--------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------|\n| `:scale_ms`  | Integer indicating size of bucket in milliseconds.                                                                                                                                                                                                              | `60_000`                       |\n| `:limit`     | Integer maximum count of actions within the bucket. In other words, the maximum number of requests that are allowed in `:scale_ms` milliseconds.                                                                                                                | `25`                           |\n| `:result`    | The result to return when the rate limit is exceeded.                                                                                                                                                                                                           | `{:error, :too_many_requests}` |\n| `:id`        | The name of the bucket, or a list of keys to fetch the name from the context or arguments. The bucket will always be scoped per field.                                                                                                                          | `\"default\"`                    |\n| `:id_source` | The source of the ID, either `:static`, `:context`, or `:arguments`. When the source is `:static`, `:id` will be used as the name of the bucket. Otherwise, the Absinthe context or the arguments passed to the field respectively will be indexed using `:id`. | `:static`                      |\n\nThe default values can be configured in your `config.exs`:\n\n    config :absinthe_rate_limiting,\n      scale_ms: 60_000,\n      limit: 25,\n      result: {:error, :too_many_requests},\n      id: \"default\",\n      id_source: :static\n\nThese values can be overridden for each field in the schema definition by\npassing them as options to the middleware:\n\n    field :my_field, :string do\n      middleware AbsintheRateLimiting.RateLimit, limit: 10\n      resolve &MyApp.Resolvers.my_field/3\n    end","ref":"AbsintheRateLimiting.RateLimit.html#module-configuration"},{"type":"module","title":"Disabling rate limiting - AbsintheRateLimiting.RateLimit","doc":"Rate limiting can be disabled by setting the `:active` configuration option to\n`false` in your `config.exs`:\n\n    config :absinthe_rate_limiting,\n      active: false\n\nThis will bypass the rate limiting middleware and allow all requests to pass\nthrough. This can be useful for testing or development environments.","ref":"AbsintheRateLimiting.RateLimit.html#module-disabling-rate-limiting"},{"type":"extras","title":"AbsintheRateLimiting","doc":"# AbsintheRateLimiting\n\n[![Hex.pm](https://img.shields.io/hexpm/v/absinthe_rate_limiting.svg)](https://hex.pm/packages/absinthe_rate_limiting)\n\n<!-- README START -->\n\n`absinthe_rate_limiting` is a middleware-based rate limiter for\n[Absinthe](https://hexdocs.pm/absinthe/overview.html) that uses\n[Hammer](https://hexdocs.pm/hammer/index.html).","ref":"readme.html"},{"type":"extras","title":"Installation - AbsintheRateLimiting","doc":"`absinthe_rate_limiting` is [available in\nHex](https://hexdocs.pm/absinthe_rate_limiting), and can be installed by adding\n`:absinthe_rate_limiting` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:absinthe_rate_limiting, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic usage - AbsintheRateLimiting","doc":"To use the rate limiting middleware, you must first configure Hammer. For example:\n\n```elixir\nconfig :hammer,\n  backend:\n    {Hammer.Backend.ETS, [\n      expiry_ms: 1000 * 60 * 60 * 4,\n      cleanup_interval_ms: 1000 * 60 * 10\n    ]}\n```\n\nSee the [Hammer documentation](https://hexdocs.pm/hammer) for more information.\n\nThe next step is to add the middleware to the query that needs to be rate\nlimited:\n\n```elixir\nfield :my_field, :string do\n  middleware AbsintheRateLimiting.RateLimit\n  resolve &MyApp.Resolvers.my_field/3\nend\n```\n\nFor the full usage information, see `AbsintheRateLimiting.RateLimit`.\n\n<!-- README END -->","ref":"readme.html#basic-usage"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}